@@ -7,7 +7,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2008, kitone
+ *	Copyright @ 2005-2009, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -304,6 +304,12 @@ public:
 	 */
 	void emit_signal(const std::string &name);
 
+	/*
+	 * Return the name of the current column focus. 
+	 * (start, end, duration, text, translation ...)
+	 */
+	Glib::ustring get_current_column_name();
+
 protected:
 	friend class Command;
 	friend class Subtitle;
