@@ -7,7 +7,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2008, kitone
+ *	Copyright @ 2005-2009, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -72,6 +72,18 @@ public:
 	 */
 	bool getline(Glib::ustring &line);
 
+	/*
+	 * Return all lines detected of the file, without newline character (CR, LF or CRLF).
+	 */
+	std::vector<Glib::ustring> get_lines();
+
+private:
+
+	/*
+	 * Split the data to separate lines.
+	 */
+	void initialize_lines();
+
 protected:
 	Glib::ustring m_uri;
 	Glib::ustring m_data;
