@@ -4,7 +4,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2008, kitone
+ *	Copyright @ 2005-2009, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -347,6 +347,17 @@ Subtitle Subtitles::get_first_selected()
 	return selection[0];
 }
 
+/*
+ *
+ */
+void Subtitles::select(std::vector<Subtitle> &sub)
+{
+	for(unsigned int i=0; i< sub.size(); ++i)
+	{
+		m_document.get_subtitle_view()->get_selection()->select(sub[i].m_iter);
+	}
+}
+
 /*
  *
  */
