@@ -7,7 +7,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2008, kitone
+ *	Copyright @ 2005-2009, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -57,6 +57,12 @@ public:
 	 */
 	static Glib::ustring get_column_label_by_name(const Glib::ustring &name);
 
+	/*
+	 * Return the name of the current column focus. 
+	 * (start, end, duration, text, translation ...)
+	 */
+	Glib::ustring get_current_column_name();
+
 protected:	
 	void loadCfg();
 
