@@ -4,7 +4,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2008, kitone
+ *	Copyright @ 2005-2009, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -139,180 +139,6 @@ void dialog_error(const Glib::ustring &primary_text, const Glib::ustring &second
 }
 
 
-
-
-
-#ifdef HAVE_ISO_CODES
-
-#include <fstream>
-#include <map>
-
-#define ISO_639_DOMAIN	"iso_639"
-#define ISO_3166_DOMAIN	"iso_3166"
-
-/*
- * max length of sscanf'ed fields + 1
- */
-#define ISO_639_2_TERMINOLOGY_LEN	4
-#define ISO_639_2_BIBLIOGRAPHY_LEN	4
-#define ISO_639_1_CODE_LEN	3
-#define ISO_639_NAME_LEN	256
-
-#define ISO_3166_ALPHA2_LEN	3
-#define ISO_3166_NAME_LEN	256
-
-static bool map_iso_639_initialised = false;
-static bool map_iso_3166_initialised = false;
-
-std::map<Glib::ustring, Glib::ustring> map_iso_639;
-std::map<Glib::ustring, Glib::ustring> map_iso_3166;
-
-/*
- *
- */
-void read_iso_639(const Glib::ustring &filename)
-{
-	std::ifstream file(filename.c_str());
-	if(!file)
-	{
-		std::cerr << "Cannot open file: " << filename << std::endl;
-		return;
-	}
-
-	std::string line;
-	
-
-	gchar *format = g_strdup_printf("%%%is %%%is %%%is %%n%%%ic%%n",
-			ISO_639_2_TERMINOLOGY_LEN - 1,
-			ISO_639_2_BIBLIOGRAPHY_LEN - 1,
-			ISO_639_1_CODE_LEN - 1,
-			ISO_639_NAME_LEN - 1);
-
-	char terminology[ISO_639_2_TERMINOLOGY_LEN];
-	char bibliography[ISO_639_2_BIBLIOGRAPHY_LEN];
-	char code[ISO_639_1_CODE_LEN];
-	char name[ISO_639_NAME_LEN];
-	int plen, nlen;
-	
-	while(!file.eof() && std::getline(file, line))
-	{
-		if(!line.empty() && line[0] != '#')
-		{
-			if(sscanf(line.c_str(), format, terminology, bibliography, code, &plen, name, &nlen) > 0)
-			{
-				if(nlen - plen > 0 && std::string(code) != "XX")
-				{
-					name[nlen - plen] = '\0';
-					map_iso_639[code]=name;
-				}
-			}
-		}
-	}
-	g_free(format);
-
-	file.close();
-
-	map_iso_639_initialised = true;
-}
-
-
-/*
- *
- */
-void read_iso_3166(const Glib::ustring &filename)
-{
-	std::ifstream file(filename.c_str());
-	if(!file)
-	{
-		std::cerr << "Cannot open file: " << filename << std::endl;
-		return;
-	}
-
-	std::string line;
-
-	gchar *format = g_strdup_printf("%%%is %%n%%%ic%%n",
-			ISO_3166_ALPHA2_LEN - 1,
-			ISO_3166_NAME_LEN - 1);
-	char code[ISO_3166_ALPHA2_LEN];
-	char name[ISO_3166_NAME_LEN];
-	int plen, nlen;
-
-	while(!file.eof() && std::getline(file, line))
-	{
-		if(!line.empty() && line[0] != '#')
-		{
-			if(sscanf(line.c_str(), format, code, &plen, name, &nlen) > 0)
-			{
-				name[nlen - plen] = '\0';
-				map_iso_3166[code]=name;
-			}
-		}
-	}
-	g_free(format);
-
-	file.close();
-
-	map_iso_3166_initialised = true;
-}
-
-
-/*
- *
- */
-void initialised()
-{
-	//bindtextdomain (ISO_639_DOMAIN, ISO_CODES_PATH);
-	bind_textdomain_codeset (ISO_639_DOMAIN, "UTF-8");
-
-	//bindtextdomain(ISO_3166_DOMAIN, ISO_CODES_PATH);
-	bind_textdomain_codeset (ISO_3166_DOMAIN, "UTF-8");
-
-	read_iso_639(Glib::build_filename(ISO_CODES_PATH, "iso_639.tab"));
-	read_iso_3166(Glib::build_filename(ISO_CODES_PATH, "iso_3166.tab"));
-}
-
-/*
- *
- */
-Glib::ustring get_iso_name_for_lang_code(const Glib::ustring &code)
-{
-	Glib::ustring c1, c2;
-
-	if(!map_iso_639_initialised)
-		initialised();
-
-	if(code.size() == 2)
-	{
-		c1 = code.substr(0, 2);
-		
-		Glib::ustring s639 = dgettext(ISO_639_DOMAIN, map_iso_639[c1].c_str());
-
-		return s639;
-	}
-	else if(code.size() == 5)
-	{
-		c1 = code.substr(0, 2);
-		c2 = code.substr(3, 5);
-
-		Glib::ustring s639 = dgettext(ISO_639_DOMAIN, map_iso_639[c1].c_str());
-		Glib::ustring s3166 = dgettext(ISO_3166_DOMAIN, map_iso_3166[c2].c_str());
-	
-		return s639 + " (" + s3166 + ")";
-	}
-
-	return code;
-}
-
-#else //HAVE_ISO_CODES
-
-Glib::ustring get_iso_name_for_lang_code(const Glib::ustring &code)
-{
-	return code;
-}
-
-#endif //HAVE_ISO_CODES
-
-
 namespace utility
 {
 	bool string_to_bool(const std::string &str)
