@@ -4,7 +4,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2008, kitone
+ *	Copyright @ 2005-2009, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -41,9 +41,9 @@ GStreamerPlayer::GStreamerPlayer()
 	m_pipeline_state = GST_STATE_NULL;
 	m_pipeline_duration = GST_CLOCK_TIME_NONE;
 
-	modify_bg(Gtk::STATE_NORMAL, Gdk::Color("black"));
-
 	add_events(Gdk::EXPOSURE_MASK);
+	unset_flags(Gtk::DOUBLE_BUFFERED);
+	set_flags(Gtk::APP_PAINTABLE);
 
 	show();
 
@@ -499,6 +499,11 @@ bool GStreamerPlayer::on_expose_event(GdkEventExpose *ev)
 			gst_x_overlay_expose(GST_X_OVERLAY(m_video_output));
 		}
 	}
+	else
+	{
+		// black canvas
+		get_window()->draw_rectangle(get_style()->get_black_gc(), TRUE, 0, 0, get_width(), get_height());
+	}
 	
 	return true;
 }
